==> perfetto_53.0.orig.tar.gz: perfetto-53.0/ui/src/plugins/dev.perfetto.WidgetsPage/sample_data.ts <==
// Copyright (C) 2025 The Android Open Source Project
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

export const languages = [
  {
    id: 1,
    lang: 'TypeScript',
    year: 2012,
    creator: 'Microsoft',
    typing: 'Static',
  },
  {
    id: 2,
    lang: 'JavaScript',
    year: 1995,
    creator: 'Brendan Eich',
    typing: 'Dynamic',
  },
  {
    id: 3,
    lang: 'Python',
    year: 1991,
    creator: 'Guido van Rossum',
    typing: 'Dynamic',
  },
  {
    id: 4,
    lang: 'Java',
    year: 1995,
    creator: 'James Gosling',
    typing: 'Static',
  },
  {
    id: 5,
    lang: 'C++',
    year: 1985,
    creator: 'Bjarne Stroustrup',
    typing: 'Static',
  },
  {
    id: 6,
    lang: 'Go',
    year: 2009,
    creator: 'Google',
    typing: 'Static',
  },
  {
    id: 7,
    lang: 'Rust',
    year: 2010,
    creator: 'Graydon Hoare',
    typing: 'Static',
  },
  {
    id: 8,
    lang: 'Ruby',
    year: 1995,
    creator: 'Yukihiro Matsumoto',
    typing: 'Dynamic',
  },
  {
    id: 9,
    lang: 'Swift',
    year: 2014,
    creator: 'Apple',
    typing: 'Static',
  },
  {
    id: 10,
    lang: 'Kotlin',
    year: 2011,
    creator: 'JetBrains',
    typing: 'Static',
  },
  {
    id: 11,
    lang: 'PHP',
    year: 1995,
    creator: 'Rasmus Lerdorf',
    typing: 'Dynamic',
  },
  {
    id: 12,
    lang: 'C#',
    year: 2000,
    creator: 'Microsoft',
    typing: 'Static',
  },
  {
    id: 13,
    lang: 'Perl',
    year: 1987,
    creator: 'Larry Wall',
    typing: 'Dynamic',
  },
  {
    id: 14,
    lang: 'Scala',
    year: 2004,
    creator: 'Martin Odersky',
    typing: 'Static',
  },
  {
    id: 15,
    lang: 'Haskell',
    year: 1990,
    creator: 'Lennart Augustsson, et al.',
    typing: 'Static',
  },
  {
    id: 16,
    lang: 'Lua',
    year: 1993,
    creator: 'Roberto Ierusalimschy, et al.',
    typing: 'Dynamic',
  },
  {
    id: 17,
    lang: 'Dart',
    year: 2011,
    creator: 'Google',
    typing: 'Static',
  },
  {
    id: 18,
    lang: 'Elixir',
    year: 2012,
    creator: 'José Valim',
    typing: 'Dynamic',
  },
  {
    id: 19,
    lang: 'Clojure',
    year: 2007,
    creator: 'Rich Hickey',
    typing: 'Dynamic',
  },
  {
    id: 20,
    lang: 'F#',
    year: 2005,
    creator: 'Microsoft',
    typing: 'Static',
  },
  {
    id: 21,
    lang: 'Lisp',
    year: 1958,
    creator: 'John McCarthy',
    typing: 'Dynamic',
  },
  {
    id: 22,
    lang: 'R',
    year: 1993,
    creator: 'Ross Ihaka and Robert Gentleman',
    typing: 'Dynamic',
  },
  {
    id: 23,
    lang: 'MATLAB',
    year: 1984,
    creator: 'Cleve Moler',
    typing: 'Dynamic',
  },
  {
    id: 24,
    lang: 'Objective-C',
    year: 1984,
    creator: 'Brad Cox and Tom Love',
    typing: 'Static',
  },
  {
    id: 25,
    lang: 'Visual Basic',
    year: 1991,
    creator: 'Microsoft',
    typing: 'Static',
  },
  {
    id: 26,
    lang: 'Fortran',
    year: 1957,
    creator: 'John Backus',
    typing: 'Static',
  },
  {
    id: 27,
    lang: 'COBOL',
    year: 1959,
    creator: 'CODASYL',
    typing: 'Static',
  },
  {
    id: 28,
    lang: 'OCaml',
    year: 1996,
    creator: 'INRIA',
    typing: 'Static',
  },
  {
    id: 29,
    lang: 'Erlang',
    year: 1986,
    creator: 'Joe Armstrong, et al.',
    typing: 'Dynamic',
  },
  {
    id: 30,
    lang: 'Groovy',
    year: 2003,
    creator: 'James Strachan',
    typing: 'Dynamic',
  },
  {
    id: 31,
    lang: 'Julia',
    year: 2012,
    creator: 'Jeff Bezanson, et al.',
    typing: 'Dynamic',
  },
  {
    id: 32,
    lang: 'C',
    year: 1972,
    creator: 'Dennis Ritchie',
    typing: 'Static',
  },
  {
    id: 33,
    lang: 'Assembly',
    year: 1949,
    creator: 'Kathleen Booth',
    typing: 'Static',
  },
  {
    id: 34,
    lang: 'Pascal',
    year: 1970,
    creator: 'Niklaus Wirth',
    typing: 'Static',
  },
  {
    id: 35,
    lang: 'Ada',
    year: 1980,
    creator: 'Jean Ichbiah',
    typing: 'Static',
  },
  {
    id: 36,
    lang: 'Scheme',
    year: 1975,
    creator: 'Guy L. Steele and Gerald Jay Sussman',
    typing: 'Dynamic',
  },
  {
    id: 37,
    lang: 'Prolog',
    year: 1972,
    creator: 'Alain Colmerauer',
    typing: 'Dynamic',
  },
  {
    id: 38,
    lang: 'Smalltalk',
    year: 1972,
    creator: 'Alan Kay, et al.',
    typing: 'Dynamic',
  },
  {
    id: 39,
    lang: 'ActionScript',
    year: 1998,
    creator: 'Gary Grossman',
    typing: 'Dynamic',
  },
  {
    id: 40,
    lang: 'D',
    year: 2001,
    creator: 'Walter Bright',
    typing: 'Static',
  },
  {
    id: 41,
    lang: 'Nim',
    year: 2008,
    creator: 'Andreas Rumpf',
    typing: 'Static',
  },
  {
    id: 42,
    lang: 'Crystal',
    year: 2014,
    creator: 'Ary Borenszweig',
    typing: 'Static',
  },
  {
    id: 43,
    lang: 'Zig',
    year: 2016,
    creator: 'Andrew Kelley',
    typing: 'Static',
  },
  {
    id: 44,
    lang: 'V',
    year: 2019,
    creator: 'Alexander Medvednikov',
    typing: 'Static',
  },
  {
    id: 45,
    lang: 'Racket',
    year: 1995,
    creator: 'PLT Inc.',
    typing: 'Dynamic',
  },
  {
    id: 46,
    lang: 'Common Lisp',
    year: 1984,
    creator: 'Scott Fahlman, et al.',
    typing: 'Dynamic',
  },
  {
    id: 47,
    lang: 'Bash',
    year: 1989,
    creator: 'Brian Fox',
    typing: 'Dynamic',
  },
  {
    id: 48,
    lang: 'PowerShell',
    year: 2006,
    creator: 'Jeffrey Snover',
    typing: 'Dynamic',
  },
  {
    id: 49,
    lang: 'Tcl',
    year: 1988,
    creator: 'John Ousterhout',
    typing: 'Dynamic',
  },
  {
    id: 50,
    lang: 'AWK',
    year: 1977,
    creator: 'Alfred Aho, et al.',
    typing: 'Dynamic',
  },
  {
    id: 51,
    lang: 'Verilog',
    year: 1984,
    creator: 'Phil Moorby',
    typing: 'Static',
  },
  {
    id: 52,
    lang: 'VHDL',
    year: 1980,
    creator: 'U.S. Department of Defense',
    typing: 'Static',
  },
  {
    id: 53,
    lang: 'Solidity',
    year: 2014,
    creator: 'Gavin Wood',
    typing: 'Static',
  },
  {
    id: 54,
    lang: 'Apex',
    year: 2007,
    creator: 'Salesforce',
    typing: 'Static',
  },
  {
    id: 55,
    lang: 'Hack',
    year: 2014,
    creator: 'Facebook',
    typing: 'Static',
  },
  {
    id: 56,
    lang: 'CoffeeScript',
    year: 2009,
    creator: 'Jeremy Ashkenas',
    typing: 'Dynamic',
  },
  {
    id: 57,
    lang: 'Elm',
    year: 2012,
    creator: 'Evan Czaplicki',
    typing: 'Static',
  },
  {
    id: 58,
    lang: 'PureScript',
    year: 2013,
    creator: 'Phil Freeman',
    typing: 'Static',
  },
  {
    id: 59,
    lang: 'Idris',
    year: 2007,
    creator: 'Edwin Brady',
    typing: 'Static',
  },
  {
    id: 60,
    lang: 'Agda',
    year: 2007,
    creator: 'Ulf Norell',
    typing: 'Static',
  },
  {
    id: 61,
    lang: 'Coq',
    year: 1989,
    creator: 'INRIA',
    typing: 'Static',
  },
  {
    id: 62,
    lang: 'Lean',
    year: 2013,
    creator: 'Leonardo de Moura',
    typing: 'Static',
  },
  {
    id: 63,
    lang: 'APL',
    year: 1966,
    creator: 'Kenneth E. Iverson',
    typing: 'Dynamic',
  },
  {
    id: 64,
    lang: 'J',
    year: 1990,
    creator: 'Kenneth E. Iverson and Roger Hui',
    typing: 'Dynamic',
  },
  {
    id: 65,
    lang: 'K',
    year: 1993,
    creator: 'Arthur Whitney',
    typing: 'Dynamic',
  },
  {
    id: 66,
    lang: 'Q',
    year: 2003,
    creator: 'Arthur Whitney',
    typing: 'Dynamic',
  },
  {
    id: 67,
    lang: 'ReasonML',
    year: 2016,
    creator: 'Jordan Walke',
    typing: 'Static',
  },
  {
    id: 68,
    lang: 'Raku',
    year: 2015,
    creator: 'Larry Wall',
    typing: 'Dynamic',
  },
  {
    id: 69,
    lang: 'Red',
    year: 2011,
    creator: 'Nenad Rakocevic',
    typing: 'Dynamic',
  },
  {
    id: 70,
    lang: 'Rebol',
    year: 1997,
    creator: 'Carl Sassenrath',
    typing: 'Dynamic',
  },
  {
    id: 71,
    lang: 'Forth',
    year: 1970,
    creator: 'Charles H. Moore',
    typing: 'Dynamic',
  },
  {
    id: 72,
    lang: 'PostScript',
    year: 1984,
    creator: 'John Warnock and Chuck Geschke',
    typing: 'Dynamic',
  },
  {
    id: 73,
    lang: 'Logo',
    year: 1967,
    creator: 'Wally Feurzeig, et al.',
    typing: 'Dynamic',
  },
  {
    id: 74,
    lang: 'BASIC',
    year: 1964,
    creator: 'John G. Kemeny and Thomas E. Kurtz',
    typing: 'Dynamic',
  },
  {
    id: 75,
    lang: 'Algol',
    year: 1958,
    creator: 'Committee',
    typing: 'Static',
  },
  {
    id: 76,
    lang: 'PL/I',
    year: 1964,
    creator: 'IBM',
    typing: 'Static',
  },
  {
    id: 77,
    lang: 'Simula',
    year: 1962,
    creator: 'Ole-Johan Dahl and Kristen Nygaard',
    typing: 'Static',
  },
  {
    id: 78,
    lang: 'BCPL',
    year: 1966,
    creator: 'Martin Richards',
    typing: 'Static',
  },
  {
    id: 79,
    lang: 'B',
    year: 1969,
    creator: 'Ken Thompson',
    typing: 'Static',
  },
  {
    id: 80,
    lang: 'Miranda',
    year: 1985,
    creator: 'David Turner',
    typing: 'Static',
  },
  {
    id: 81,
    lang: 'ML',
    year: 1973,
    creator: 'Robin Milner',
    typing: 'Static',
  },
  {
    id: 82,
    lang: 'SML',
    year: 1983,
    creator: 'Robin Milner, et al.',
    typing: 'Static',
  },
  {
    id: 83,
    lang: 'Eiffel',
    year: 1986,
    creator: 'Bertrand Meyer',
    typing: 'Static',
  },
  {
    id: 84,
    lang: 'Modula-2',
    year: 1978,
    creator: 'Niklaus Wirth',
    typing: 'Static',
  },
  {
    id: 85,
    lang: 'Oberon',
    year: 1986,
    creator: 'Niklaus Wirth',
    typing: 'Static',
  },
  {
    id: 86,
    lang: 'Icon',
    year: 1977,
    creator: 'Ralph Griswold',
    typing: 'Dynamic',
  },
  {
    id: 87,
    lang: 'SNOBOL',
    year: 1962,
    creator: 'Ralph Griswold, et al.',
    typing: 'Dynamic',
  },
  {
    id: 88,
    lang: 'Scratch',
    year: 2003,
    creator: 'MIT Media Lab',
    typing: 'Dynamic',
  },
  {
    id: 89,
    lang: 'Blockly',
    year: 2012,
    creator: 'Google',
    typing: 'Dynamic',
  },
  {
    id: 90,
    lang: 'LabVIEW',
    year: 1986,
    creator: 'National Instruments',
    typing: 'Dynamic',
  },
  {
    id: 91,
    lang: 'Chapel',
    year: 2009,
    creator: 'Cray Inc.',
    typing: 'Static',
  },
  {
    id: 92,
    lang: 'X10',
    year: 2004,
    creator: 'IBM',
    typing: 'Static',
  },
  {
    id: 93,
    lang: 'Pony',
    year: 2012,
    creator: 'Sylvan Clebsch',
    typing: 'Static',
  },
  {
    id: 94,
    lang: 'Ballerina',
    year: 2017,
    creator: 'WSO2',
    typing: 'Static',
  },
  {
    id: 95,
    lang: 'Ring',
    year: 2016,
    creator: 'Mahmoud Fayed',
    typing: 'Dynamic',
  },
  {
    id: 96,
    lang: 'Grain',
    year: 2017,
    creator: 'Oscar Spencer and Blaine Bublitz',
    typing: 'Static',
  },
  {
    id: 97,
    lang: 'Odin',
    year: 2016,
    creator: 'Ginger Bill',
    typing: 'Static',
  },
  {
    id: 98,
    lang: 'Carbon',
    year: 2022,
    creator: 'Google',
    typing: 'Static',
  },
  {
    id: 99,
    lang: 'Mojo',
    year: 2023,
    creator: 'Modular',
    typing: 'Static',
  },
  {
    id: 100,
    lang: 'Gleam',
    year: 2016,
    creator: 'Louis Pilfold',
    typing: 'Static',
  },
];

==> perfetto_54.0.orig.tar.gz: perfetto-54.0/ui/src/plugins/dev.perfetto.WidgetsPage/sample_data.ts <==
// Copyright (C) 2025 The Android Open Source Project
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

export const languages = [
  {
    id: 1,
    lang: 'TypeScript',
    year: 2012,
    creator: 'Microsoft',
    typing: 'Static',
    execution: 'Transpiled',
  },
  {
    id: 2,
    lang: 'JavaScript',
    year: 1995,
    creator: 'Brendan Eich',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 3,
    lang: 'Python',
    year: 1991,
    creator: 'Guido van Rossum',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 4,
    lang: 'Java',
    year: 1995,
    creator: 'James Gosling',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 5,
    lang: 'C++',
    year: 1985,
    creator: 'Bjarne Stroustrup',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 6,
    lang: 'Go',
    year: 2009,
    creator: 'Google',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 7,
    lang: 'Rust',
    year: 2010,
    creator: 'Graydon Hoare',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 8,
    lang: 'Ruby',
    year: 1995,
    creator: 'Yukihiro Matsumoto',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 9,
    lang: 'Swift',
    year: 2014,
    creator: 'Apple',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 10,
    lang: 'Kotlin',
    year: 2011,
    creator: 'JetBrains',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 11,
    lang: 'PHP',
    year: 1995,
    creator: 'Rasmus Lerdorf',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 12,
    lang: 'C#',
    year: 2000,
    creator: 'Microsoft',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 13,
    lang: 'Perl',
    year: 1987,
    creator: 'Larry Wall',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 14,
    lang: 'Scala',
    year: 2004,
    creator: 'Martin Odersky',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 15,
    lang: 'Haskell',
    year: 1990,
    creator: 'Lennart Augustsson, et al.',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 16,
    lang: 'Lua',
    year: 1993,
    creator: 'Roberto Ierusalimschy, et al.',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 17,
    lang: 'Dart',
    year: 2011,
    creator: 'Google',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 18,
    lang: 'Elixir',
    year: 2012,
    creator: 'José Valim',
    typing: 'Dynamic',
    execution: 'Compiled',
  },
  {
    id: 19,
    lang: 'Clojure',
    year: 2007,
    creator: 'Rich Hickey',
    typing: 'Dynamic',
    execution: 'Compiled',
  },
  {
    id: 20,
    lang: 'F#',
    year: 2005,
    creator: 'Microsoft',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 21,
    lang: 'Lisp',
    year: 1958,
    creator: 'John McCarthy',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 22,
    lang: 'R',
    year: 1993,
    creator: 'Ross Ihaka and Robert Gentleman',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 23,
    lang: 'MATLAB',
    year: 1984,
    creator: 'Cleve Moler',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 24,
    lang: 'Objective-C',
    year: 1984,
    creator: 'Brad Cox and Tom Love',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 25,
    lang: 'Visual Basic',
    year: 1991,
    creator: 'Microsoft',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 26,
    lang: 'Fortran',
    year: 1957,
    creator: 'John Backus',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 27,
    lang: 'COBOL',
    year: 1959,
    creator: 'CODASYL',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 28,
    lang: 'OCaml',
    year: 1996,
    creator: 'INRIA',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 29,
    lang: 'Erlang',
    year: 1986,
    creator: 'Joe Armstrong, et al.',
    typing: 'Dynamic',
    execution: 'Compiled',
  },
  {
    id: 30,
    lang: 'Groovy',
    year: 2003,
    creator: 'James Strachan',
    typing: 'Dynamic',
    execution: 'Compiled',
  },
  {
    id: 31,
    lang: 'Julia',
    year: 2012,
    creator: 'Jeff Bezanson, et al.',
    typing: 'Dynamic',
    execution: 'Compiled',
  },
  {
    id: 32,
    lang: 'C',
    year: 1972,
    creator: 'Dennis Ritchie',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 33,
    lang: 'Assembly',
    year: 1949,
    creator: 'Kathleen Booth',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 34,
    lang: 'Pascal',
    year: 1970,
    creator: 'Niklaus Wirth',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 35,
    lang: 'Ada',
    year: 1980,
    creator: 'Jean Ichbiah',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 36,
    lang: 'Scheme',
    year: 1975,
    creator: 'Guy L. Steele and Gerald Jay Sussman',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 37,
    lang: 'Prolog',
    year: 1972,
    creator: 'Alain Colmerauer',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 38,
    lang: 'Smalltalk',
    year: 1972,
    creator: 'Alan Kay, et al.',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 39,
    lang: 'ActionScript',
    year: 1998,
    creator: 'Gary Grossman',
    typing: 'Dynamic',
    execution: 'Compiled',
  },
  {
    id: 40,
    lang: 'D',
    year: 2001,
    creator: 'Walter Bright',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 41,
    lang: 'Nim',
    year: 2008,
    creator: 'Andreas Rumpf',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 42,
    lang: 'Crystal',
    year: 2014,
    creator: 'Ary Borenszweig',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 43,
    lang: 'Zig',
    year: 2016,
    creator: 'Andrew Kelley',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 44,
    lang: 'V',
    year: 2019,
    creator: 'Alexander Medvednikov',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 45,
    lang: 'Racket',
    year: 1995,
    creator: 'PLT Inc.',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 46,
    lang: 'Common Lisp',
    year: 1984,
    creator: 'Scott Fahlman, et al.',
    typing: 'Dynamic',
    execution: 'Compiled',
  },
  {
    id: 47,
    lang: 'Bash',
    year: 1989,
    creator: 'Brian Fox',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 48,
    lang: 'PowerShell',
    year: 2006,
    creator: 'Jeffrey Snover',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 49,
    lang: 'Tcl',
    year: 1988,
    creator: 'John Ousterhout',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 50,
    lang: 'AWK',
    year: 1977,
    creator: 'Alfred Aho, et al.',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 51,
    lang: 'Verilog',
    year: 1984,
    creator: 'Phil Moorby',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 52,
    lang: 'VHDL',
    year: 1980,
    creator: 'U.S. Department of Defense',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 53,
    lang: 'Solidity',
    year: 2014,
    creator: 'Gavin Wood',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 54,
    lang: 'Apex',
    year: 2007,
    creator: 'Salesforce',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 55,
    lang: 'Hack',
    year: 2014,
    creator: 'Facebook',
    typing: 'Static',
    execution: 'Transpiled',
  },
  {
    id: 56,
    lang: 'CoffeeScript',
    year: 2009,
    creator: 'Jeremy Ashkenas',
    typing: 'Dynamic',
    execution: 'Transpiled',
  },
  {
    id: 57,
    lang: 'Elm',
    year: 2012,
    creator: 'Evan Czaplicki',
    typing: 'Static',
    execution: 'Transpiled',
  },
  {
    id: 58,
    lang: 'PureScript',
    year: 2013,
    creator: 'Phil Freeman',
    typing: 'Static',
    execution: 'Transpiled',
  },
  {
    id: 59,
    lang: 'Idris',
    year: 2007,
    creator: 'Edwin Brady',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 60,
    lang: 'Agda',
    year: 2007,
    creator: 'Ulf Norell',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 61,
    lang: 'Coq',
    year: 1989,
    creator: 'INRIA',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 62,
    lang: 'Lean',
    year: 2013,
    creator: 'Leonardo de Moura',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 63,
    lang: 'APL',
    year: 1966,
    creator: 'Kenneth E. Iverson',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 64,
    lang: 'J',
    year: 1990,
    creator: 'Kenneth E. Iverson and Roger Hui',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 65,
    lang: 'K',
    year: 1993,
    creator: 'Arthur Whitney',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 66,
    lang: 'Q',
    year: 2003,
    creator: 'Arthur Whitney',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 67,
    lang: 'ReasonML',
    year: 2016,
    creator: 'Jordan Walke',
    typing: 'Static',
    execution: 'Transpiled',
  },
  {
    id: 68,
    lang: 'Raku',
    year: 2015,
    creator: 'Larry Wall',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 69,
    lang: 'Red',
    year: 2011,
    creator: 'Nenad Rakocevic',
    typing: 'Dynamic',
    execution: 'Compiled',
  },
  {
    id: 70,
    lang: 'Rebol',
    year: 1997,
    creator: 'Carl Sassenrath',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 71,
    lang: 'Forth',
    year: 1970,
    creator: 'Charles H. Moore',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 72,
    lang: 'PostScript',
    year: 1984,
    creator: 'John Warnock and Chuck Geschke',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 73,
    lang: 'Logo',
    year: 1967,
    creator: 'Wally Feurzeig, et al.',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 74,
    lang: 'BASIC',
    year: 1964,
    creator: 'John G. Kemeny and Thomas E. Kurtz',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 75,
    lang: 'Algol',
    year: 1958,
    creator: 'Committee',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 76,
    lang: 'PL/I',
    year: 1964,
    creator: 'IBM',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 77,
    lang: 'Simula',
    year: 1962,
    creator: 'Ole-Johan Dahl and Kristen Nygaard',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 78,
    lang: 'BCPL',
    year: 1966,
    creator: 'Martin Richards',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 79,
    lang: 'B',
    year: 1969,
    creator: 'Ken Thompson',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 80,
    lang: 'Miranda',
    year: 1985,
    creator: 'David Turner',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 81,
    lang: 'ML',
    year: 1973,
    creator: 'Robin Milner',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 82,
    lang: 'SML',
    year: 1983,
    creator: 'Robin Milner, et al.',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 83,
    lang: 'Eiffel',
    year: 1986,
    creator: 'Bertrand Meyer',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 84,
    lang: 'Modula-2',
    year: 1978,
    creator: 'Niklaus Wirth',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 85,
    lang: 'Oberon',
    year: 1986,
    creator: 'Niklaus Wirth',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 86,
    lang: 'Icon',
    year: 1977,
    creator: 'Ralph Griswold',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 87,
    lang: 'SNOBOL',
    year: 1962,
    creator: 'Ralph Griswold, et al.',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 88,
    lang: 'Scratch',
    year: 2003,
    creator: 'MIT Media Lab',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 89,
    lang: 'Blockly',
    year: 2012,
    creator: 'Google',
    typing: 'Dynamic',
    execution: 'Transpiled',
  },
  {
    id: 90,
    lang: 'LabVIEW',
    year: 1986,
    creator: 'National Instruments',
    typing: 'Dynamic',
    execution: 'Compiled',
  },
  {
    id: 91,
    lang: 'Chapel',
    year: 2009,
    creator: 'Cray Inc.',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 92,
    lang: 'X10',
    year: 2004,
    creator: 'IBM',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 93,
    lang: 'Pony',
    year: 2012,
    creator: 'Sylvan Clebsch',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 94,
    lang: 'Ballerina',
    year: 2017,
    creator: 'WSO2',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 95,
    lang: 'Ring',
    year: 2016,
    creator: 'Mahmoud Fayed',
    typing: 'Dynamic',
    execution: 'Interpreted',
  },
  {
    id: 96,
    lang: 'Grain',
    year: 2017,
    creator: 'Oscar Spencer and Blaine Bublitz',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 97,
    lang: 'Odin',
    year: 2016,
    creator: 'Ginger Bill',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 98,
    lang: 'Carbon',
    year: 2022,
    creator: 'Google',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 99,
    lang: 'Mojo',
    year: 2023,
    creator: 'Modular',
    typing: 'Static',
    execution: 'Compiled',
  },
  {
    id: 100,
    lang: 'Gleam',
    year: 2016,
    creator: 'Louis Pilfold',
    typing: 'Static',
    execution: 'Compiled',
  },
];
